@@ -1,14 +1,19 @@
 package EventStore::Tiny::Logger;
-use Mo qw(default);
 
-has print_target => sub {select}; # selected output file handle
+use strict;
+use warnings;
+
+use Class::Tiny {
+    print_target => sub {select}, # selected output file handle
+};
 
 sub log {
     my ($self, $event) = @_;
 
     # stringify
     use Data::Dump 'dump';
-    my $output = $event->name . ': ' . dump $event->data;
+    my $data    = $event->can('data') ? dump $event->data : 'NO DATA';
+    my $output = $event->name . ": $data";
 
     # print to given print handle
     $self->print_target->print("$output\n");
