@@ -1,8 +1,20 @@
 package EventStore::Tiny::Snapshot;
-use Mo qw(default required );
 
-has state       => (required => 1);
-has timestamp   => (required => 1, is => 'ro');
+use strict;
+use warnings;
+
+use Class::Tiny {
+    state       => sub {die "state is required.\n"},
+    timestamp   => sub {die "timestamp is required.\n"},
+};
+
+sub BUILD {
+    my $self = shift;
+
+    # check non-lazy
+    $self->state;
+    $self->timestamp;
+}
 
 1;
 
